Name:           mapserver
Version:        6.2.1
Release:        %mkrel 10
Summary:        Web-based Map Server
License:        BSD
Group:          Sciences/Geosciences
URL:            http://mapserver.org/

Source0:        http://download.osgeo.org/mapserver/mapserver-%{version}.tar.gz
Patch0:		mapserver-6.2.1-gdver.patch
Patch1:		mapserver-6.2.1-link.patch
BuildRequires:  xpm-devel
BuildRequires:  readline-devel
BuildRequires:  apache-devel
BuildRequires:  php-devel
BuildRequires:  libxslt-devel
BuildRequires:  pam-devel
BuildRequires:  libfcgi-devel
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  perl-devel
BuildRequires:  postgresql-devel
BuildRequires:  mysql-devel
BuildRequires:  java-devel
BuildRequires:  swig > 1.3.24 
#BuildRequires:  java
#BuildRequires:  java-1.5.0-gcj-devel
BuildRequires:  geos-devel
BuildRequires:  proj-devel
BuildRequires:  gdal-devel
BuildRequires:  agg-devel
BuildRequires:  cairo-devel
BuildRequires:  php-devel
BuildRequires:  freetype-devel
BuildRequires:  gd-devel >= 2.0.16
BuildRequires:  python-devel
BuildRequires:  curl-devel
BuildRequires:  zlib-devel
BuildRequires:  libxml2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  fribidi-devel
BuildRequires:  giflib-devel

Requires:       webserver
Requires:       fonts-ttf-bitstream-vera
Requires:       proj

%description
MapServer is an  OpenSource development environment for building spatially
enabled Internet applications. The software builds upon other popular
OpenSource or freeware systems like Shapelib, FreeType, Proj.4, libTIFF,
Perl and others.

The MapServer CGI application provides a significant number of
"out-of-the-box" features. Here's a sampling:

* vector formats supported: ESRI shapefiles, simple embedded features,
  ESRI ArcSDE (alpha release)
* raster formats supported (8-bit only): TIFF/GeoTIFF, GIF, PNG, ERDAS,
  JPEG and EPPL7
* quadtree spatial indexing for shapefiles
* fully customizable, template driven output
* feature selection by item/value, point, area or another feature
* TrueType font support
* support for tiled raster and vector data (display only)
* automatic legend and scalebar building
* scale dependent feature drawing and application execution
* thematic map building using logical or regular expression based classes
* feature labeling including label collision mediation
* on-the-fly configuration via URLs
* on-the-fly projection

MapServer is not a full-featured GIS system, nor does it aspire to be.
It does, however, provide enough core functionality to support a wide
variety of web applications. Beyond browsing GIS data, MapServer allows
you create "geographic image maps", that is, maps that can direct users
to content.

%package php
Summary:        PHP/Mapscript map making extensions to PHP
Group:          Development/PHP
Requires:       webserver php-gd
Provides:       php-mapscript
Obsoletes:      php-mapscript < %{version}-%{release}

%description php
The PHP/Mapscript extension provides full map customization capabilities within
the PHP scripting language.


%package perl
Summary:        Perl/Mapscript map making extensions to Perl
Group:          Development/Perl
Requires:       %{name} = %{version}-%{release}
#Requires: perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

%description perl
The Perl/Mapscript extension provides full map customization capabilities
within the Perl programming language.

%package python
Summary:        Python/Mapscript map making extensions to Python
Group:          Development/Python
Requires:       %{name} = %{version}-%{release}

%description python
The Python/Mapscript extension provides full map customization capabilities
within the Python programming language.

%package java
Summary:        Java/Mapscript map making extensions to Java
Group:          Development/Java
Requires:       %{name} = %{version}-%{release}
Requires:       java-gcj-compat 

%description java
The Java/Mapscript extension provides full map customization capabilities
within the Java programming language.

%prep
%setup -q
%patch0 -p1
%patch1 -p0 -b .orig
# fix spurious perm bits
chmod -x tests/home.png
chmod -x mapscript/php/php_mapscript.c
chmod -x mappluginlayer.c
chmod -x mapscript/php/mapscript_i.c
chmod -x mapscript/php/examples/test_writeshape.phtml
chmod -x mapscript/python/examples/*.py
chmod -x mapscript/python/tests/rundoctests.dist
chmod -x mapscript/perl/examples/*.pl
chmod -x mapscript/php/README


# remove fonts
# alias as symlinks
rm -rf tests/vera/Vera.ttf
rm -rf tests/vera/VeraBd.ttf
pushd tests/vera/
ln -sf /usr/share/fonts/bitstream-vera/Vera.ttf Vera.ttf
ln -sf /usr/share/fonts/bitstream-vera/VeraBd.ttf VeraBd.ttf
popd

%build
CFLAGS="${CFLAGS} -ldl" ; export CFLAGS

# fix a UTF-8 one
iconv -f ISO-8859-1 -t UTF-8 < \
mapscript/java/examples/QueryByAttributeUnicode.java > \
mapscript/java/examples/QueryByAttributeUnicode-tmp.java
mv -f mapscript/java/examples/QueryByAttributeUnicode-tmp.java \
mapscript/java/examples/QueryByAttributeUnicode.java

# fix gdal lookup
autoreconf -fi

%define _disable_ld_no_undefined 1
%configure2_5x \
   --with-gd \
   --with-freetype=%{_bindir}/freetype-config \
   --with-gdal=%{_bindir}/gdal-config \
   --with-ogr=%{_bindir}/gdal-config \
   --with-geos=%{_bindir}/geos-config \
   --with-cairo=yes \
   --with-proj \
   --with-wfs \
   --with-wcs \
   --with-sos \
   --with-wmsclient \
   --with-wfsclient \
   --with-postgis=%{_bindir}/pg_config \
   --with-curl-config=%{_bindir}/curl-config \
   --with-xml2-config=%{_bindir}/xml2-config \
   --with-php=%{_bindir}/php-config \
   --with-fribidi-config=%{_libdir}/pkgconfig/fribidi.pc \
   --with-fastcgi=%{_prefix} \
   --with-threads \
   --enable-debug

# disable pgport library lookup.
for makefile in `find . -type f -name 'Makefile'`; do
sed -i 's|-lpgport||g' $makefile
done

# WARNING !!!
# using %{?_smp_mflags} may break build

%make

# build perl
cd mapscript/perl
perl Makefile.PL
make -j1

# build python
cd ../python
python setup.py build

# disable java build for now, since it breaks the build
# TODO: solve this
# build java
#cd ../java
#make interface
#make

%install

mkdir -p %{buildroot}/%{_sbindir}
mkdir -p %{buildroot}/%{_sysconfdir}/php.d
mkdir -p %{buildroot}%{_libdir}/php/extensions
mkdir -p %{buildroot}/%{_var}/www/cgi-bin
mkdir -p %{buildroot}/%{_var}/www/html/mapserver/tmp

%makeinstall_std

install -p -m 755 mapserv %{buildroot}/%{_var}/www/cgi-bin
install -p -m 755 shp2img %{buildroot}/%{_var}/www/cgi-bin
install -p -m 755 shptree %{buildroot}/%{_var}/www/cgi-bin
install -p -m 755 sortshp %{buildroot}/%{_var}/www/cgi-bin
install -p -m 755 tile4ms %{buildroot}/%{_var}/www/cgi-bin
install -p -m 755 legend %{buildroot}/%{_var}/www/cgi-bin
install -p -m 755 shptreevis %{buildroot}/%{_var}/www/cgi-bin
install -p -m 755 shptreetst %{buildroot}/%{_var}/www/cgi-bin
install -p -m 755 scalebar %{buildroot}/%{_var}/www/cgi-bin

#install -p -m 755 mapscript/php/php_mapscript.so %{buildroot}/%{_libdir}/php/extensions/

# install perl module
pushd mapscript/perl
make DESTDIR=%{buildroot} pure_vendor_install
popd

# install python module
pushd mapscript/python
python setup.py install --root %{buildroot}
popd

# install java
#mkdir -p %{buildroot}%{_javadir}
#install -p -m 644 mapscript/java/mapscript.jar %{buildroot}%{_javadir}/

# install php config file
mkdir -p %{buildroot}%{_sysconfdir}/php.d/
cat > %{buildroot}%{_sysconfdir}/php.d/40_%{name}.ini <<EOF
; Enable %{name} extension module
extension=php_mapscript.so
EOF

# cleanup junks
for junk in {*.pod,*.bs,.packlist} ; do
find %{buildroot} -name "$junk" -exec rm -rf '{}' \;
done

# fix some exec bits
chmod 755 %{buildroot}/%{perl_vendorarch}/auto/mapscript/mapscript.so

# remove la files
find %{buildroot} -name "*.la" -delete
rm -f %{buildroot}%{_libdir}/libmapserver.so

%files
%doc README COMMITERS GD-COPYING HISTORY.TXT  
%doc INSTALL MIGRATION_GUIDE.txt
%doc symbols tests
%doc fonts
%{_var}/www/cgi-bin/*
%dir %{_var}/www/html/mapserver
%dir %{_var}/www/html/mapserver/tmp
%{_bindir}/*
%{_libdir}/libmapserver-%{version}.so

%files php
%doc mapscript/php/README
%doc mapscript/php/examples
%config(noreplace) %{_sysconfdir}/php.d/40_%{name}.ini
%{_libdir}/php/extensions/php_mapscript.so
%{_libdir}/php/extensions/php_mapscript-%{version}.so

%files perl
%doc mapscript/perl/examples
%dir %{perl_vendorarch}/auto/mapscript
%{perl_vendorarch}/auto/mapscript/*
%{perl_vendorarch}/mapscript.pm

%files python
%doc mapscript/python/README
%doc mapscript/python/examples
%doc mapscript/python/tests
%{python_sitearch}/*

#%files java
#%doc mapscript/java/README
#%doc mapscript/java/examples
#%doc mapscript/java/tests
#%{_javadir}/*.jar


%changelog
* Fri Jan 24 2014 pterjan <pterjan> 6.2.1-10.mga4
+ Revision: 567613
- Rebuild for new PHP

* Tue Oct 22 2013 umeabot <umeabot> 6.2.1-9.mga4
+ Revision: 542778
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 pterjan <pterjan> 6.2.1-8.mga4
+ Revision: 497873
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Aug 26 2013 stormi <stormi> 6.2.1-7.mga4
+ Revision: 471958
- require proj (mga #7102)

* Wed Jun 26 2013 fwang <fwang> 6.2.1-6.mga4
+ Revision: 446831
- fix wrong lib inclusion

* Wed Jun 26 2013 fwang <fwang> 6.2.1-5.mga4
+ Revision: 446822
- use system ldflags

* Wed Jun 26 2013 fwang <fwang> 6.2.1-4.mga4
+ Revision: 446818
- rebuild for new geos

* Sun Jun 02 2013 fwang <fwang> 6.2.1-3.mga4
+ Revision: 434935
- rebuild for new libpng

* Wed May 29 2013 fwang <fwang> 6.2.1-2.mga4
+ Revision: 430418
- rebuild for new perl

* Tue May 28 2013 fwang <fwang> 6.2.1-1.mga4
+ Revision: 429341
- more condition
- fix detect on gdlib

  + oden <oden>
    - rebuilt against libgd.so.3

  + obgr_seneca <obgr_seneca>
    - New version 6.2.0

* Sat Jan 12 2013 fwang <fwang> 6.0.1-10.mga3
+ Revision: 359581
- add upstream patch to build with php 5.4

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jun 20 2012 obgr_seneca <obgr_seneca> 6.0.1-9.mga3
+ Revision: 262170
- disable mapscript-java for now since it breaks the build
- Rebuild against new geos

* Thu May 31 2012 fwang <fwang> 6.0.1-8.mga3
+ Revision: 251963
- rebuild for new perl

* Wed Apr 04 2012 luigiwalser <luigiwalser> 6.0.1-7.mga2
+ Revision: 228526
- httpd restart is handled by filetriggers now

* Tue Jan 17 2012 obgr_seneca <obgr_seneca> 6.0.1-6.mga2
+ Revision: 197274
- removed explicit java-1.6.0 br
- java-devel is already required
- rebuild for new libgeos
- fixed upstream Url

* Thu Nov 03 2011 obgr_seneca <obgr_seneca> 6.0.1-5.mga2
+ Revision: 162067
- rebuild against new geos

* Wed Oct 05 2011 obgr_seneca <obgr_seneca> 6.0.1-4.mga2
+ Revision: 151595
- fixed php_mapscript install path

* Tue Sep 27 2011 obgr_seneca <obgr_seneca> 6.0.1-3.mga2
+ Revision: 149573
- rebuild against new geos and changes in gdal

* Fri Sep 16 2011 obgr_seneca <obgr_seneca> 6.0.1-2.mga2
+ Revision: 144269
- fixed dependencies

* Fri Sep 16 2011 obgr_seneca <obgr_seneca> 6.0.1-1.mga2
+ Revision: 144241
- new version 6.0.1
- added bindings for perl and python
- renamed php-mapscript tp mapserver-php to have a unified maning schema
- thanks to Devrim Gunduz, Marcela Maslanova and others at Fedora from whom I borrowed parts of the spec file

* Wed Apr 20 2011 obgr_seneca <obgr_seneca> 5.6.6-1.mga2
+ Revision: 89062
- cleaned up new spec
- corrected upstream url
- new version 5.6.6
- imported package mapserver


* Sat Aug 21 2010 Funda Wang <fwang@mandriva.org> 5.6.5-2mdv2011.0
+ Revision: 571655
- fix linkage

* Mon Aug 09 2010 Buchan Milne <bgmilne@mandriva.org> 5.6.5-1mdv2011.0
+ Revision: 567989
- update to new version 5.6.5
- Fix postgresql/postgis buildrequires

* Fri Apr 23 2010 Buchan Milne <bgmilne@mandriva.org> 5.6.3-1mdv2010.1
+ Revision: 538157
- buildrequire readline-devel
- update to new version 5.6.3

* Thu Oct 08 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 5.2.1-6mdv2010.0
+ Revision: 455894
- rebuild for new curl SSL backend

* Mon Oct 05 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.2.1-5mdv2010.0
+ Revision: 454294
- disable parallel build to fix build
- rebuild for new libdap

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Raphaël Gertz <rapsys@mandriva.org>
    - Rebuild

* Sat Jan 24 2009 Funda Wang <fwang@mandriva.org> 5.2.1-2mdv2009.1
+ Revision: 333299
- rebuild

  + Buchan Milne <bgmilne@mandriva.org>
    - New version 5.2.1
    - Fix "format not a string literal"

* Fri Aug 22 2008 Funda Wang <fwang@mandriva.org> 5.2.0-1mdv2009.0
+ Revision: 275025
- New version 5.2.0

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Buchan Milne <bgmilne@mandriva.org>
    - Enable ming and geos support
    - New version 5.0.3

* Mon Mar 03 2008 Buchan Milne <bgmilne@mandriva.org> 5.0.2-1mdv2008.1
+ Revision: 178226
- New version 5.0.2

  + Thierry Vignaud <tv@mandriva.org>
    - fix no-buildroot-tag
    - kill re-definition of %%buildroot on Pixel's request

* Fri Aug 24 2007 Helio Chissini de Castro <helio@mandriva.com> 4.10.3-1mdv2008.0
+ Revision: 71038
- New upstream version
- mapscript builds against php 5 since 4.8
- Added postgis support
- Changed mapscript package name to match other php packages

* Tue Aug 21 2007 Buchan Milne <bgmilne@mandriva.org> 4.10.2-1mdv2008.0
+ Revision: 68453
- Buildrequire cfitsio-devel
- Buildrequire netcdf-devel
- Buildrequire php4-devel on recent distros
- New version 4.10.2
- Fix PHP detection (use cpp instead of grep) with multiarched headers


* Sat Jan 27 2007 Emmanuel Andry <eandry@mandriva.org> 4.10.0-2mdv2007.0
+ Revision: 114441
- buildrequires apache-mpm-prefork

  + Nicolas Lécureuil <neoclust@mandriva.org>
    - Rebuild against new curl

  + David Walluck <walluck@mandriva.org>
    - Import mapserver

* Tue Oct 31 2006 Franck Martin <franck@sopac.org> 4.10.0-1mdk
- New Release 4.10.0

* Tue Sep 05 2006 Franck Martin <franck@sopac.org> 4.8.4-1mdk
- New Release 4.8.4

* Tue Sep 13 2005 Franck Martin <franck@sopac.org> 4.6.1-1mdk
- New release 4.6.1

* Thu Jul 21 2005 Franck Martin <franck@sopac.org> 4.6.0-1mdk
- New release 4.6.0
- includes php mapscript

* Sun Jul 18 2004 Michael Scherer <misc@mandrake.org> 4.2.1-1mdk
- New release 4.2.1
- rpmbuildupdate aware

